#!/usr/bin/env bash

if [ -z $1 ]; then
	echo "usage: $0 {test host}"
	exit 1
fi

TESTHOST=$1

running_cs=`ssh $TESTHOST "ps -ef | grep CastorScript | grep -v -c grep"`

if [ "$running_cs" != "0" ]; then
	echo "error: there seems to be some CastorScript running on $TESTHOST"
	exit 2
else
	echo "OK: no running CastorScript instances on $TESTHOST"
fi

KEYTAB_FILE="/daq_area/castor/$TESTHOST/atlascdr/atlascdr.keytab"
if ! ssh $TESTHOST "sudo -u atlascdr -i cat $KEYTAB_FILE &>/dev/null"; then
	echo "error: keytab file not readble by atlascdr ($KEYTAB_FILE)"
	exit 3
else
	echo "OK: readable keytab file: $KEYTAB_FILE"
fi

CASTOR_SCRIPT_CONFIG_FILE=test_config.cfg
if ! sed -r "s:/daq_area/castor/[a-zA-Z0-9-]+/atlascdr/atlascdr.keytab:/daq_area/castor/$TESTHOST/atlascdr/atlascdr.keytab:" $CASTOR_SCRIPT_CONFIG_FILE -i; then
	echo "error: cannot modify CastorScript config file: $CASTOR_SCRIPT_CONFIG_FILE"
	exit 4
else
	echo "OK: CastorScript config file modified: $CASTOR_SCRIPT_CONFIG_FILE "
fi

SOURCE_DIR=`pwd`/..
REMOTE_DIR="/eos/atlas/atlastier0/daq/test/CastorScript.tests"

ssh $TESTHOST sudo -u atlascdr -i $SOURCE_DIR/Test/p1.test.atlascdr.bash
