#!/bin/env python

##### Thread checking constantly the state of the partition #####
import os
import threading
import logging
from cs.Tools.utils import set_log_level,formatter,thread_id_string


class CheckThread(threading.Thread):

    def __init__(self, conf, manager, copy, delete, event, logger, ERS_handler):

        threading.Thread.__init__(self, name="CheckThread")

        import ers
        from ispy import IPCPartition #pylint: disable=no-name-in-module
        self.IPCPartition = IPCPartition

        self.conf = conf
        self.event = event
        self.manager = manager
        self.copy = copy
        self.delete = delete

        ##### Main logger #####
        self.logger = logger
        self.ERS_handler = ERS_handler

        ##### Get configuration parameters #####
        self.CheckTimeout = self.conf.CheckTimeout
        self.ERSLogLevel = self.conf.ERSLogLevel
        self.LogDir = self.conf.LogDir
        self.ERSenabled = self.conf.ERSenabled
        self.partition = self.conf.partition
        self.LogLevel = self.conf.LogLevel
        self.ERSTimeout = self.conf.ERSTimeout

        ##### Define Thread internal variables #####
        self.exitFlag = False
        self.ers_flag = True

        ##### Set Logger for CheckThread #####
        self.logFile = os.path.join(self.LogDir,'CheckLog.out')
        self.CheckLog = logging.FileHandler(self.logFile,'w')
        self.CheckLog.setFormatter(formatter)

        self.check_logger = logging.getLogger('CheckThread')
        self.check_logger.addHandler(self.CheckLog)

        ##### Add ERS handler #####
        if self.ERSenabled:
            try:
                self.check_ERS_handler=ers.LoggingHandler()
                set_log_level(self.ERSLogLevel,self.check_ERS_handler)
                self.check_logger.addHandler( self.check_ERS_handler )
            except Exception,ex:
                self.check_logger.error("CheckThread could not create ERS, reason is '%s'", str(ex))
    # end def __init__()


    def run(self):

        self.logger.info(thread_id_string())

        ##### Set Logger Level #####
        set_log_level(self.LogLevel, self.CheckLog)

        while True:

            ##### Don't stay in this loop forever #####
            if self.exitFlag:
                return

            ##### Check for a new partition #####
            if self.IPCPartition(self.partition).isValid() and not self.ers_flag:
                self.event.wait(self.ERSTimeout)
                self.check_logger.warning('Found partition %s, adding ERS', self.partition)
                self.ers_flag = True
                ##### Add ERS handlers to all loggers #####
                self.change_state_ers(True)

            ##### Check for the disappearance of partition #####
            elif self.ers_flag and not self.IPCPartition(self.partition).isValid():
                self.check_logger.warning('Lost connection to partition %s, removing ERS handlers', self.partition)
                self.ers_flag = False
                ##### Remove ERS handlers from all loggers #####
                self.change_state_ers(False)
            self.event.wait(self.CheckTimeout)

        # end while
    # end def run()


    ##### Call add/remove ERS functions from threads #####
    def change_state_ers(self, create_ers_handler):
        if create_ers_handler:
            ##### Add ERS handler to all loggers #####
            self.logger.addHandler(self.ERS_handler)
            self.check_logger.addHandler(self.check_ERS_handler)
            self.copy.AddRemoveERS(True)
            self.manager.AddRemoveERS(True)
            if self.delete:
                self.delete.AddRemoveERS(True)
        else:
            ##### Remove ERS from all loggers #####
            self.logger.removeHandler(self.ERS_handler)
            self.check_logger.removeHandler(self.check_ERS_handler)
            self.copy.AddRemoveERS(False)
            self.manager.AddRemoveERS(False)
            if self.delete:
                self.delete.AddRemoveERS(False)
        # end if,else
    # end def change_state_ers()


    ##### Exit handler #####
    def checkExit(self):
        self.exitFlag = True
        self.check_logger.info('Exit signal received')
    # end def checkExit()
