#!/bin/env python

import os.path
import sys

if __name__ == "__main__":
    from os.path import dirname, abspath, join

    # add /../../CastorScript/Script to path so imports keeps working
    SCRIPT_DIR = abspath(join(dirname(__file__), '..','..',".."))
    sys.path.append(SCRIPT_DIR)

from cs.Tools.FilenameParsers.SFOFileNameParser import SFOFileNameParser

BASEDIR = '/castor/cern.ch/grid/atlas/tzero/prod1/perm/'


def MergedMigrated(castorfile, stager, pool, backend, logger=None, verbose=False):
    """
Destination directory:
/<basedir>/<projecttag>/<streamtype_streamname>/<runnr-7digit>/<dataset>/

basedir = /castor/cern.ch/grid/atlas/tzero/prod1/perm/
projecttag = data09_cos
dataset = data09_cos.00122050.physics_IDCosmic.merge.RAW

Merged file name is:

1) if all SFO files of a LB fit into a single file
  <project>.<runnr>.<stream>.daq.RAW._lbXXXX._SFO-N._<fileseqnr>.data, N=4,5,9,10
  --> <project>.<runnr>.<stream>.merge.RAW._lbXXXX._SFO-ALL._0001.<attemptnr>

2) if all SFO files of a LB don't fit into a single file
  <project>.<runnr>.<stream>.daq.RAW._lbXXXX._SFO-N._<fileseqnr>.data, N=4,5,9,10
  --> <project>.<runnr>.<stream>.merge.RAW._lbXXXX._SFO-N._<fileseqnr>.<attemptnr>, N=4,5,9,10
  """
    ### Build the target directory name
    parsed = SFOFileNameParser(os.path.basename(castorfile))

    dataset = '%s.%s.%s_%s.merge.RAW' \
              % (parsed.ProjectTag(), parsed.RunNr(), \
                 parsed.StreamType(), parsed.StreamName())


    path = os.path.join(BASEDIR, parsed.ProjectTag(), \
                        '%s_%s' % (parsed.StreamType(), parsed.StreamName()), \
                        '%s' % parsed.RunNr(), \
                        '%s' % dataset)
    if verbose:
        print path

    ### Look for files into the dataset dir
    success, all_files = backend.listdir(path, stager, pool, logger)

    ### If fails, return false
    if not success: return False

    ### Create the two type of name we expect (neglecting attempt number)
    notmerged = os.path.splitext(os.path.basename(castorfile))[0]
    notmerged = notmerged.replace('.daq.','.merge.')
    merged = '.'.join(notmerged.split('.',6)[:-1]+['_SFO-ALL._0001'])

    ### Find all the files with the correct name
    files = [f for f in all_files
             if f and (notmerged in f or merged in f)]

    if not files: return False

    ### Take the file with the highest attempt number
    filename = sorted([(int(f.rsplit('.',1)[1]),f) for f in files])[-1][1]

    ### Check the migration status for the file
    return backend.migrated(os.path.join(path, filename),
                            stager, pool, logger)

if __name__ == '__main__':

    import importlib
    backend_module = importlib.import_module("cs.StorageBackends.castorstorage")

    print MergedMigrated(sys.argv[1], sys.argv[2], sys.argv[3],
                         backend_module, verbose=True)
