
import logging
import zlib
import ctypes
import time
import datetime

#### Set Log severity level #####
def set_log_level(level, logger):

    level = level.upper()

    levelmap = {'DEBUG':logging.DEBUG,
                'INFO':logging.INFO,
                'WARNING':logging.WARNING,
                'ERROR':logging.ERROR,
                'CRITICAL':logging.CRITICAL}

    logger.setLevel(levelmap[level])

formatter = logging.Formatter('%(asctime)s %(levelname)-8s [%(filename)s:%(lineno)d] %(message)s')

def gettid():
    #This is linux specific ...
    SYS_gettid = 186
    libc = ctypes.cdll.LoadLibrary('libc.so.6')
    tid = libc.syscall(SYS_gettid)
    return tid


def thread_id_string():
    import threading
    me = threading.currentThread()
    return '%s TID: %d' % (me.getName(),gettid())


def adler32(filename):
    BS = 1024*1024
    f = open(filename, 'rb')

    ck = 1
    while True:
        data = f.read(BS)
        if not data: break
        ck = zlib.adler32(data,ck)

    return ('%x' % ctypes.c_uint(ck).value).zfill(8)


def get_tx_bytes(device):

    with open('/proc/net/dev', 'r') as f:
        lines = f.readlines()

    device_stat = next(l for l in lines if device in l)

    return int(device_stat.split()[9])


def get_bw(device, interval=1):

    if not device:
        return -1

    tx_bytes_0 = get_tx_bytes(device)

    t0 = datetime.datetime.now()
    time.sleep(interval)
    tdiff = (datetime.datetime.now() - t0).total_seconds()

    bdiff = get_tx_bytes(device) - tx_bytes_0

    if bdiff < 0:
        # Wrap up
        return -1

    return 1.*bdiff/tdiff/1000/1000
