#!/bin/bash
shorthostname=`hostname -s`
SWDIR="/sw/castor"
CONFDIR="/daq_area/castor/${shorthostname}/${USER}"

# Prevents "*.cfg" to be returned if no files are present
shopt -s nullglob

for cfg in $CONFDIR/*.cfg; do

	logdir=$(grep LogDir $cfg | awk '{print $2}' | tr -d "'" | tr -d "\"")

	ps -ef | grep python | grep CastorScript.py | grep "$cfg" > /dev/null 2>&1

	if [ $? -eq 1 ]; then
		# If the CastorScript crashed, especially on uncaught exceptions, this watchdog
		# restarts it and we won't notice. Uncaught exception messages end up in
		# log.out: mail it to Fabrice so that he knows if the file has non-zero length.
		if [ -s $logdir/log.out ]; then
			echo "$cfg" | mail -s "CastorScript instance crashed" -a $logdir/log.out -r "atlascdr@cern.ch" flegoff@cern.ch
		fi

		# Backup previous running instance log files
		olddir=logbackup_$(date "+%Y%m%d-%H%M%S")
		mkdir -p $logdir/$olddir
		mv $logdir/*.out $logdir/$olddir
		find $logdir -maxdepth 1 -name logbackup\* -printf "%T@ %p\n" | sort -n | head -n -5 | awk '{print $2}' | xargs rm -rf

		# Source required environment
		source $SWDIR/script_setup.sh

		# Start script
		python -u $SWDIR/Script/CastorScript.py $cfg > $logdir/log.out 2>&1 &

		# Log messages
		date
		echo "Copying script restarted: $cfg"
		echo
	fi

done
